# Changelog

## v0.8.10

- deps: upgrading google-genai to it's latest version (1.1.0, with lots of bug fixes)
- fix: gemini 2.0 models not properlly mapped in the model_to_model_class mapping, which made calls to latest models fail
